package net.rzdata.mcp.server.crm;

import cn.hutool.core.lang.Assert;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson2.JSONObject;
import net.rzdata.mcp.server.crm.config.CrmProperties;
import org.springframework.ai.tool.annotation.Tool;
import org.springframework.ai.tool.annotation.ToolParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class CrmMcpService {
    @Autowired
    private CrmProperties crmProperties;

    /**
     * 公共的HTTP请求方法
     */
    private String executeRequest(String apiPath, JSONObject requestBody) {
        return HttpRequest.post(crmProperties.getApiUrl(apiPath))
                .header("tenantid", crmProperties.getTenantId())
                .header("Authorization", crmProperties.getToken())
                .body(requestBody.toString())
                .execute()
                .body();
    }


    @Tool(description = "根据客户名称或客户编码查询客户负责人")
    public String getClientResponsible(
            @ToolParam(description = "客户编码",required = false) String clientCode,
            @ToolParam(description = "客户名称",required = false) String clientName

    ) {
        Assert.isTrue(StrUtil.isNotEmpty(clientCode) || StrUtil.isNotEmpty(clientName),
                "客户编码和客户名称不能同时为空");

        JSONObject requestBody = new JSONObject();
        requestBody.put("clientCode", clientCode);
        requestBody.put("clientName", clientName);

        return executeRequest("ai/query/getClientResponsible", requestBody);
    }

    @Tool(description = "根据订单编码（即订单号）查询订单负责人")
    public String getOrderSaller(
            @ToolParam(description = "订单编码") String orderCode
    ) {
        Assert.isTrue(StrUtil.isNotEmpty(orderCode), "订单编码不能为空");

        JSONObject requestBody = new JSONObject();
        requestBody.put("orderCode", orderCode);

        return executeRequest("ai/query/getOrderSaller", requestBody);
    }

    @Tool(description = "根据客户名称或客户编码查询某个时间段内的订单销售额")
    public String sumOrderTotalForClientInTime(
            @ToolParam(description = "客户编码", required = false) String clientCode,
            @ToolParam(description = "客户名称", required = false) String clientName,
            @ToolParam(description = "开始时间", required = false) String startTime,
            @ToolParam(description = "结束时间", required = false) String endTime
    ) {

        JSONObject requestBody = new JSONObject();
        requestBody.put("clientCode", clientCode);
        requestBody.put("clientName", clientName);
        requestBody.put("startTime", startTime);
        requestBody.put("endTime", endTime);

        return executeRequest("ai/query/sumOrderTotalForClientInTime", requestBody);
    }

    @Tool(description = "根据客户名称或客户编码查询某个时间段内购买的某个产品货号的数量")
    public String sumProductNumForClientInTime(
            @ToolParam(description = "客户编码", required = false) String clientCode,
            @ToolParam(description = "客户名称", required = false) String clientName,
            @ToolParam(description = "产品货号", required = false) String productnum,
            @ToolParam(description = "开始时间", required = false) String startTime,
            @ToolParam(description = "结束时间", required = false) String endTime
    ) {
        JSONObject requestBody = new JSONObject();
        requestBody.put("clientCode", clientCode);
        requestBody.put("clientName", clientName);
        requestBody.put("productnum", productnum);
        requestBody.put("startTime", startTime);
        requestBody.put("endTime", endTime);

        return executeRequest("ai/query/sumProductNumForClientInTime", requestBody);
    }

    @Tool(description = "根据订单编码（即订单号）查询订单购买的产品明细")
    public String detailOrderProduct(
            @ToolParam(description = "订单编码") String orderCode
    ) {
        Assert.isTrue(StrUtil.isNotEmpty(orderCode), "订单编码不能为空");

        JSONObject requestBody = new JSONObject();
        requestBody.put("orderCode", orderCode);

        return executeRequest("ai/query/detailOrderProduct", requestBody);
    }

}
